@@ -1,27 +1,29 @@
 #!@PERL@ -w
 ##
-##  OSSP snmpdx -- SNMP Daemon Extension
+##  OSSP snmpdx - SNMP Daemon Extension
 ##  Copyright (c) 2003 The OSSP Project <http://www.ossp.org/>
 ##  Copyright (c) 2003 Ralf S. Engelschall <rse@engelschall.com>
 ##  Copyright (c) 2003 Cable & Wireless <http://www.cw.com/>
 ##
-##  Permission to use, copy, modify, and distribute this software for
-##  any purpose with or without fee is hereby granted, provided that
-##  the above copyright notice and this permission notice appear in all
-##  copies.
+##  This file is part of OSSP snmpdx, a SNMP daemon extension which
+##  can be found at http://www.ossp.org/pkg/tool/snmpdx/.
 ##
-##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
-##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
-##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
-##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
-##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
-##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-##  SUCH DAMAGE.
+##  This program is free software; you can redistribute it and/or
+##  modify it under the terms of the GNU General Public  License
+##  as published by the Free Software Foundation; either version
+##  2.0 of the License, or (at your option) any later version.
+##
+##  This program is distributed in the hope that it will be useful,
+##  but WITHOUT ANY WARRANTY; without even the implied warranty of
+##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+##  General Public License for more details.
+##
+##  You should have received a copy of the GNU General Public License
+##  along with this file; if not, write to the Free Software
+##  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+##  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
+##
+##  snmpdx.pl: framework program
 ##
 
 #   requirements
@@ -484,7 +486,7 @@ my $opt = {
     'get'       => 0,
     'next'      => 0,
     'set'       => 0,
-    'bindir'    => "/cw/bin",
+    'bindir'    => "@bindir@",
     'probedir'  => "@libexecdir@/snmpdx",
     'probename' => "*",
     'mibdir'    => "@datadir@/snmpdx:@snmpmibdir@",
